==> hometec_ui-1.1.8.tar.gz: lib/components/collectiion/collection_item.dart <==
import 'package:flutter/material.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/enums/image_enum.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

Widget collectionItem(CollectionItem item, {Function(BuildContext, int) onTap, BuildContext context, int index, Color textColor, ImageTypeEnum type = ImageTypeEnum.local}){
  return Center(
          child: GestureDetector(
            onTap: () => onTap != null ? onTap(context, index): null,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Container(
                    decoration: BoxDecoration(
                        border: Border.all(width: 3, color: item.getSelected() ? ECColor.secondary : ECColor.clear),
                        borderRadius: BorderRadius.circular(60.0)
                    ),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(60.0),
                      child: Container(
                        height: 60,
                        width: 60,
                        child: type == ImageTypeEnum.local ? Image.asset("images/${item.getImage()}") : Image.network(item.getImage()),
                      ),
                    ), 
                  ),
                SizedBox(height: 8),
                Text(item.getTitle(), style: Font.overlineBold.style(color: textColor == null ? item.getSelected() ? ECColor.secondary : ECColor.primary : textColor),),
              ],
            ),
          ),
        );
}

abstract class CollectionItem {
  String getImage();
  String getTitle();
  bool getSelected();
}

==> hometec_ui-1.1.21.tar.gz: lib/components/collectiion/collection_item.dart <==
import 'package:flutter/material.dart';
import 'package:hometec_ui/resources/colors/color.dart';
import 'package:hometec_ui/resources/enums/image_enum.dart';
import 'package:hometec_ui/resources/fonts/font.dart';

Widget collectionItem(CollectionItem item, {Function(BuildContext, int) onTap, BuildContext context, int index, Color textColor, ImageTypeEnum type = ImageTypeEnum.local}){
  return Center(
          child: GestureDetector(
            onTap: () => onTap != null ? onTap(context, index): null,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Container(
                    decoration: BoxDecoration(
                        border: Border.all(width: 3, color: item.getSelected() ? ECColor.primary : ECColor.clear),
                        borderRadius: BorderRadius.circular(60.0)
                    ),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(60.0),
                      child: Container(
                        height: 60,
                        width: 60,
                        child: type == ImageTypeEnum.local ? Image.asset("images/${item.getImage()}") : Image.network(item.getImage()),
                      ),
                    ), 
                  ),
                SizedBox(height: 8),
                Text(item.getTitle(), style: Font.overlineBold.style(color: textColor == null ? item.getSelected() ? ECColor.primary : ECColor.secondary : textColor),),
              ],
            ),
          ),
        );
}

abstract class CollectionItem {
  String getImage();
  String getTitle();
  bool getSelected();
}
